@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/oxnas_ox820/build/staging_dir/toolchain-arm_mpcore_gcc-7.3.0_musl_eabi/share/gcc-7.3.0/python'
-libdir = '/builder/oxnas_ox820/build/staging_dir/toolchain-arm_mpcore_gcc-7.3.0_musl_eabi/arm-openwrt-linux-muslgnueabi/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-arm_mpcore_gcc-7.5.0_musl_eabi/share/gcc-7.5.0/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-arm_mpcore_gcc-7.5.0_musl_eabi/arm-openwrt-linux-muslgnueabi/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
